@@ -1,13 +1,13 @@
 package Perinci::Access::Schemeless;
 
-our $DATE = '2016-06-10'; # DATE
-our $VERSION = '0.87'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.88'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use parent qw(Perinci::Access::Base);
 
@@ -266,7 +266,7 @@ sub _load_module {
         # load is successful
         if ($self->{after_load}) {
             eval { $self->{after_load}($self, module=>$pkg) };
-            $log->error("after_load for package $pkg dies: $@") if $@;
+            log_error("after_load for package $pkg dies: $@") if $@;
         }
     }
     $loadcache{$module_p} = $res;
@@ -1037,7 +1037,7 @@ Perinci::Access::Schemeless - Base class for Perinci::Access::Perl
 
 =head1 VERSION
 
-This document describes version 0.87 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2016-06-10.
+This document describes version 0.88 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2017-07-10.
 
 =head1 DESCRIPTION
 
@@ -1276,7 +1276,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
